@@ -98,7 +98,7 @@ def makeIndividualData(file):
     print(f'File {file.index} --> Success')
     return individual_data
 
-def getDataForUniquePrediction(jsonPath,save_fd):
+def getDataForUniquePrediction(jsonPath,saved_prediction_dataset_folder):
     test_list_of_graphs = []
     jsonAsObject = GetJsonFromFile(jsonPath)
     jsonAsDoc = ConvertJsonToDocumentsObjects(jsonAsObject)[0]
@@ -106,9 +106,8 @@ def getDataForUniquePrediction(jsonPath,save_fd):
     test_list_of_graphs.append(individual_data)
     test_data = torch_geometric.data.Batch.from_data_list(test_list_of_graphs)
     test_data.edge_attr = None
-    saved_path = os.path.join(save_fd, 'predictions_data.dataset')
+    saved_path = os.path.join(saved_prediction_dataset_folder, 'predictions_data.dataset')
     torch.save(test_data, saved_path)
-    return saved_path
 
 def load_train_test_split(save_fd):
     train_data = torch.load(os.path.join(save_fd, 'train_data.dataset'))
