@@ -6,7 +6,7 @@ import torch
 from graphmanagerlib.Graph import Grapher
 from graphmanagerlib.Data_for_gcn import load_predictionData, getDataForUniquePrediction
 from torch_geometric.utils.convert import from_networkx
-from graphmanagerlib.JsonManager import ConvertJsonToDocumentsObjects
+from graphmanagerlib.JsonManager import ConvertJsonToDocumentsObjects, GetJsonFromFile
 
 def clearOutputFolder(test_output_fd):
     shutil.rmtree(test_output_fd)
@@ -21,14 +21,14 @@ def make_info(document):
     individual_data = from_networkx(G)
     return G, df, individual_data
 
-def predictionsUnique(saved_model_folder,saved_prediction_dataset_folder,document_to_predict_json,labels_tab):
-    getDataForUniquePrediction(document_to_predict_json,saved_prediction_dataset_folder)
+def predictionsUnique(saved_model_folder,saved_prediction_dataset_folder,document_to_predict_jsonPath,labels_tab):
+    getDataForUniquePrediction(document_to_predict_jsonPath,saved_prediction_dataset_folder)
 
     predictions_data = load_predictionData(save_fd=saved_prediction_dataset_folder)
 
-    model = torch.load(saved_model_folder)
+    model = torch.load(os.path.join(saved_model_folder, "saved_model.pt"))
 
-    y_preds = model.max(dim=1)[1].cpu().numpy()
+    y_preds = model(predictions_data).max(dim=1)[1].cpu().numpy()
 
     test_batch = predictions_data.batch.cpu().numpy()
     sample_indexes = np.where(test_batch == 0)[0]
@@ -39,7 +39,8 @@ def predictionsUnique(saved_model_folder,saved_prediction_dataset_folder,documen
     """
     OBTENIR LE DOC EN DOC
     """
-    document = ConvertJsonToDocumentsObjects(document_to_predict_json)[0]
+    jsonObject = GetJsonFromFile(document_to_predict_jsonPath);
+    document = ConvertJsonToDocumentsObjects(jsonObject)[0]
     _, df, _ , _ = make_info(document)
 
     assert len(y_pred) == df.shape[0]
